@@ -5,11 +5,11 @@
 //! which is the analog operation to a convolution in time domain.
 use super::FixedLenBuffer;
 use crate::inline_vector::InlineVector;
-use num_complex::{Complex32, Complex64};
 use crate::numbers::*;
+use crate::vector_types::*;
+use num_complex::{Complex32, Complex64};
 use std::marker::PhantomData;
 use std::ops::*;
-use crate::vector_types::*;
 
 /// A convolution function in time domain and real number space
 pub trait RealImpulseResponse<T>: Sync
@@ -195,7 +195,7 @@ macro_rules! add_linear_table_lookup_impl {
 
                     /// Creates a lookup table from another convolution function. The `delta` argument
                     /// can be used to balance performance vs. accuracy.
-                    pub fn from_conv_function(other: &$conv_type<$data_type>,
+                    pub fn from_conv_function(other: &dyn $conv_type<$data_type>,
                                               delta: $data_type,
                                               len: usize) -> Self {
                         let center = len as isize;
